from Products.CMFCore.utils import getToolByName
from zope.component import getUtility
from zope.i18n import ITranslationDomain

def createTranslations(portal,canon,domain='plumi'):
    """Creates translations of 'canon' into all available languages in 'domain'"""
    parent = canon.getParentNode()
    wftool = getToolByName(portal,'portal_workflow')
    transDomain = getUtility(ITranslationDomain, domain)
    availLanguages = transDomain.getCatalogsInfo()
    langs = []
    for lang in availLanguages.keys():
        if str(lang) != 'test':
            langs.append(str(lang))
    for lang in langs:
        transId = '%s-%s' % (canon.id, lang)
        transTitle = transDomain.translate(canon.title,
                                           target_language=lang)
        transDesc = transDomain.translate(canon.description,
                                          target_language=lang)
        if not hasattr(parent, transId):
            if parent != portal and parent.hasTranslation(lang):
                #if parent folder has a translation, put the clone in that
                translation = parent.getTranslation(lang).manage_clone(canon,
                                                    transId)
            else:
                translation = parent.manage_clone(canon, transId)
            translation.setTitle(transTitle)
            translation.setDescription(transDesc)
            translation.setLanguage(lang)
            translation.addTranslationReference(canon)
            wftool.doActionFor(translation,action='publish')

def createTranslationsRecursive(portal,canon,domain='plumi'):
    """Recursively creates translations into all available languages."""
    createTranslations(portal,canon,domain)
    if canon.isPrincipiaFolderish:
        for child in canon.getChildNodes():
            createTranslationsRecursive(portal,child,domain)

def deleteTranslations(canon):
    """Deletes all the translations of 'canon'"""
    for translation in canon.getBRefs():
        canon.getParentNode().manage_delObjects(translation.id)

#probably don't need a deleteTranslationsR, since once we delete the parent(s),
#the children should be unreferenced, and get garbage-collected later on.



#setup the countries tool only for SE Asia
SE_ASIA_COUNTRIES=True

#languages to support by default
LANGUAGES = ['en','id','ms-my']

#Names of the folders inside the taxonomy hierarchy
TOPLEVEL_TAXONOMY_FOLDER='taxonomy'
GENRE_FOLDER='genre'
CATEGORIES_FOLDER='topic'
COUNTRIES_FOLDER='countries'
SUBMISSIONS_FOLDER='callouts'



from zope.i18nmessageid import MessageFactory
_ = MessageFactory("plumi")

vocab_set = {}

taxonomy_sub_folder={'topic':'video_categories','genre':'video_genre','callouts':'submission_categories','countries':''}

vocab_set['video_categories'] = (
         ('poverty', _(u'Poverty / Development')),
         ('indigenous', _(u'Indigenous')),
         ('refugee', _(u'Refugee / Migration')),
         ('health', _(u'Health')),
         ('corporations', _(u'Corporations / Privatisation')),
         ('globalisation', _(u'Globalisation')),
         ('law', _(u'Law / Justice')),
         ('work', _(u'Work')),
         ('consumerism', _(u'Consumerism')),
         ('war', _(u'War / Peace')),
         ('human', _(u'Human Rights')),
         ('disability', _(u'Disability Rights')),
         ('gender', _(u'Gender / Sexuality')),
         ('race', _(u'Race')),
         ('religion', _(u'Religion')),
         ('art', _(u'Art / Culture')),
         ('internet', _(u'Internet')),
         ('media', _(u'Media')),
         ('activism', _(u'Activism')),
         ('politics', _(u'Politics')),
         ('education', _(u'Education')),
         ('biodiversity', _(u'Biodiversity')),
         ('climate', _(u'Climate Change')),
         ('conservation', _(u'Forests / Conservation')),
         ('nuclear', _(u'Nuclear')),
         ('sustainablity', _(u'Sustainability')),
         ('animal', _(u'Animal Rights')),
         ('water', _(u'Water')),
         ('biotech', _(u'Biotech')),
         ('civillib',_(u'Civil Liberties')),
        )
vocab_set['video_genre'] = (
         ('documentary', _(u'Documentary')),
         ('experimental', _(u'Experimental')),
         ('fiction', _(u'Fiction')),
         ('animation', _(u'Animation')),
         ('music', _(u'Music')),
         ('newsreport', _(u'News Report')),
        )
vocab_set['submission_categories'] = (
         ('festival', _(u'Festival')),
         ('screening', _(u'Screening')),
         ('dvd', _(u'DVD')),
         ('production', _(u'Production')),
         ('conference', _(u'Conference')),
         ('workshop', _(u'Workshop')),
         ('crew', _(u'Crew')),
         ('competition', _(u'Competition')),
         ('artprize', _(u'Art Prize')),
         ('exhibition',_(u'Exhibition')),
         ('other', _(u'Other')),
        ) 




"""This package adds extensions to portal_catalog.
"""

from zope.interface import providedBy, Interface
from Acquisition import aq_inner
from Products.CMFPlone.CatalogTool import registerIndexableAttribute
from Products.CMFCore.utils import getToolByName
from plumi.content.interfaces import IPlumiVideo
import logging

def hasImageAndCaption(object,portal, **kw):
    logger=logging.getLogger('plumi.app.policy.catalog_extension')
    if not IPlumiVideo.providedBy(object):
        return None
   
    logger.debug('hasImageAndCaption - have %s ' % object )
    img = object.getThumbnailImage()
    #check that the image is set
    if img is not None and img is not '':
	caption = object.getThumbnailImageDescription() or u''
        md = {'image': True, 'caption': caption }
    else:     
	md = {'image': False, 'caption': u''}

    logger.debug(' hasImageAndCaption returning %s  . thumbnail object is %s' % (md, object.getThumbnailImage()))
    return md

def isTranscodedPlumiVideoObj(object, portal, **kw):
    logger=logging.getLogger('plumi.app.policy.catalog_extension')

    if not IPlumiVideo.providedBy(object):
        return None

    logger.debug(' isTranscodedPlumiVideoObj - have %s ' % object )
    # XXX reimplement this.
    # using the PMH Grok web app 

    #statuses = TRANSCODING_STATUSES
    #status = str(object.getIndyTubeStatus())
    #if status in statuses:
    #    video_status = statuses.get(status, (False, u""))
    #    if video_status[0]:
    #            indytube_html = object.getIndyTubeHTML()
    #    else:
    #            indytube_html = ""
    #else:
    video_status = (False, u"")
    indytube_html = ""

    return { 'transcoding_status':video_status[0], 'indytube_html':indytube_html }

def isPublishablePlumiVideoObj(object, portal, **kw):
    logger=logging.getLogger('plumi.app.policy.catalog_extension')

    if not IPlumiVideo.providedBy(object):
        return None

    logger.debug(' isPublishablePlumiVideoObj - have %s ' % object )

    portal_workflow = getToolByName(portal,'portal_workflow')
    portal_membership = getToolByName(portal,'portal_membership')
    portal_contentlicensing = getToolByName(portal,'portal_contentlicensing')

    #wf state
    item_state = portal_workflow.getInfoFor(object, 'review_state', '')
    #name of creator 
    member_name = object.Creator()
    #get the actual user object
    user = portal_membership.getMemberById(member_name)
    portal.plone_log("Item %s by %s is in state %s. user is %s " % (object.absolute_url(), member_name, item_state,user))
    if user is None:
        portal.plone_log("No matching members??")

    if user is not None and item_state == 'published':
        (url,length,type) = object.getFileAttribs()
        cclicense = portal_contentlicensing.getLicenseAndHolderFromObject(object)
        cclicense_text = portal_contentlicensing.DefaultSiteLicense[0]
        cclicense_url  = None
        if cclicense[1][1] != 'None':
                cclicense_text = cclicense[1][1]
        if cclicense[1][2] != 'None':
                cclicense_url  = cclicense[1][2]


        d = { 'published':True,
              'item_title': object.Title(),
              'item_creator_email': user.getProperty('email',''),
              'item_creator_fullname':user.getProperty('fullname',''),
              'subject': object.Subject(),
              'item_rfc822_datetime': DateTime(object.Date()).rfc822(),
              'item_rfc3339_datetime': DateTime(object.Date()).HTML4(),
              'file_url': url,
              'file_length':length,
              'file_type':type,
              'item_url':object.absolute_url(),
              'license_text':cclicense_text,
              'license_url':cclicense_url
            }

    else:
        d = {'published': False }

    return d

#
# Register these indexable attributes
registerIndexableAttribute('hasImageAndCaption', hasImageAndCaption)
registerIndexableAttribute('isTranscodedPlumiVideoObj', isTranscodedPlumiVideoObj)
registerIndexableAttribute('isPublishablePlumiVideoObj', isPublishablePlumiVideoObj)



import logging
from Products.CMFCore.utils import getToolByName

#i18n
from zope.i18nmessageid import MessageFactory
_ = MessageFactory("plumi")

exclude_filter = [ 'syndication_information' ]
def updateCreatorAndOwnership(container, member_id,object):
    plone_utils = getToolByName(container,'plone_utils') 
    ids_to_update = [ o for o in object.objectIds() if o not in exclude_filter ]
    for o in ids_to_update:
        obj = getattr(object, o)
        obj.setCreators([member_id])

        logging.info('updateCreatorAndOwnership : object is %s object type is %s, creators %s ' %  (o,obj.getTypeInfo().getId(),obj.Creators()))
        try:
            plone_utils.changeOwnershipOf (obj, member_id, 1)
        except KeyError:
            #special case, we must be using a user outside of this plone site, 
            #eg an admin user defined in a higher level
            pass
        #call recursively on sub-objects
        updateCreatorAndOwnership(container,member_id,obj)


def notifyMemberAreaCreated(container,context):
    ''' Called when a user logins in for the first time, and enable user folders is enabled'''
    logger=logging.getLogger('plumi.app.member_area')
    logger.info('starting notifyMemberAreaCreated , container is %s , context is %s' % (container,context))

    # this is the plone folder that holds the default member content
    default_member_content = getattr(container, 'default_member_content', None)
    portal_membership = getToolByName(container,'portal_membership') 
    workflow = getToolByName(container,'portal_workflow')

    #XXX this assumption is broken on importing members from CSV file.
    memb = portal_membership.getAuthenticatedMember()
    member_id = memb.getId()
    #hack around above bug. It manifests itself as everyone owned by 'admin' usually.
    if member_id == 'admin':
        #get name from folder context name
            member_id = context.getId()

    logger.info('found member, is %s ' % member_id) 
    # here we do the copying
    copy_ids = default_member_content.objectIds()
    #exclude
    id_filter = ['.personal']
    copy_ids = [id for id in copy_ids if id not in id_filter]
    objects = default_member_content.manage_copyObjects(copy_ids)
    context.manage_pasteObjects(objects)
    logger.info('copied objects from default member content')
 
    context.manage_fixupOwnershipAfterAdd()

    #publish the members folder, and whatever got copied into it.
    workflow.doActionFor(context,'publish')
    for pubobj in context.objectIds():
        logging.info('publishing %s ' % pubobj)
        obj2 = getattr(context, pubobj)
        workflow.doActionFor(obj2, 'publish')

    #finally, acquire ownership for the new member
    #run the recursive update creator and ownership
    updateCreatorAndOwnership(container,member_id,context)
 
    logger.info('ending notifyMemberAreaCreated')



import transaction
import logging
from Products.CMFCore.utils import getToolByName
from plumi.app.install import app_installation_tasks

#install plumi.skin last
PRODUCT_DEPENDENCIES = ('LinguaPlone','plone.contentratings','vaporisation','ATVocabularyManager','ATCountryWidget','ContentLicensing','PressRoom','Marshall','collective.flowplayer','plumi.content','plone.app.blob', 'collective.contentlicensing', 'plone.app.imaging', 'plumi.migration', 'json_migrator', 'collective.plonebookmarklets', 'quintagroup.plonecomments', 'plumi.skin')

# These are deprecated products, and will be removed in plumi 0.5.x
PRODUCT_DEPENDENCIES_LEGACY=('qPloneComments','qRSS2Syndication',)
                        
EXTENSION_PROFILES = ('plumi.app:default',)

def install(self, reinstall=False):
    """Install a set of products (which themselves may either use Install.py
    or GenericSetup extension profiles for their configuration) and then
    install a set of extension profiles.
    
    One of the extension profiles we install is that of this product. This
    works because an Install.py installation script (such as this one) takes
    precedence over extension profiles for the same product in 
    portal_quickinstaller. 
    
    We do this because it is not possible to install other products during
    the execution of an extension profile (i.e. we cannot do this during
    the importVarious step for this profile).
    """
    logger = logging.getLogger('plumi.app')
    logger.info('starting install')
    portal_quickinstaller = getToolByName(self, 'portal_quickinstaller')
    portal_setup = getToolByName(self, 'portal_setup')
    logger.info('starting product dependencies')
    for product in PRODUCT_DEPENDENCIES:
        if reinstall and portal_quickinstaller.isProductInstalled(product):
            portal_quickinstaller.reinstallProducts([product])
            transaction.savepoint()
        elif not portal_quickinstaller.isProductInstalled(product):
            portal_quickinstaller.installProduct(product)
            transaction.savepoint()
    logger.info('starting dependencies legacy')
    for product in PRODUCT_DEPENDENCIES_LEGACY:
        if reinstall and portal_quickinstaller.isProductInstalled(product):
            portal_quickinstaller.reinstallProducts([product])
            transaction.savepoint()
        elif not portal_quickinstaller.isProductInstalled(product):
            portal_quickinstaller.installProduct(product)
            transaction.savepoint()
    logger.info('starting extension profiles')
    for extension_id in EXTENSION_PROFILES:
        portal_setup.runAllImportStepsFromProfile('profile-%s' % extension_id, purge_old=False)
        product_name = extension_id.split(':')[0]
        portal_quickinstaller.notifyInstalled(product_name)
        transaction.savepoint()
    #run custom setup code.
    logger.info('starting custom setup code')
    app_installation_tasks(self)
    logger.info('end install')




import logging
from zope.app.component.interfaces import ISite
from plone.app.controlpanel.security import ISecuritySchema

from plumi.app.vocabs  import vocab_set as vocabs
from plumi.app.config import TOPLEVEL_TAXONOMY_FOLDER , GENRE_FOLDER, CATEGORIES_FOLDER, COUNTRIES_FOLDER, SUBMISSIONS_FOLDER, SE_ASIA_COUNTRIES, LANGUAGES

#imports from old style plone 'Products' namespace
from Products.CMFCore.utils import getToolByName
from Products.ATVocabularyManager.config import TOOL_NAME as ATVOCABULARYTOOL
from Products.ATCountryWidget.CountryTool import CountryUtils, Country
from Products.CMFCore.WorkflowCore import WorkflowException
from Products.Five.component import enableSite

from AccessControl import allow_module
allow_module('plumi.app.member_area.py')

#i18n
from zope.i18nmessageid import MessageFactory
_ = MessageFactory("plumi")
from plumi.app.translations import createTranslations, deleteTranslations


def initialize(context):  
    """Initializer called when used as a Zope 2 product."""
    logger=logging.getLogger('plumi.app')
    logger.debug('beginning initialize')
    # this is called at Zope instance startup, ie not installation.
    logger.debug('ending  initialize')

def publishObject(wftool,obj):
    logger=logging.getLogger('plumi.app')
    try:
        logger.info('publishing %s ' % obj)
        wftool.doActionFor(obj,action='publish')
    except WorkflowException:
        logger.error('caught workflow exception!') 
        pass

def app_installation_tasks(self):
    """Custom Plumi setup code"""
    logger=logging.getLogger('plumi.app')

    logger.info('starting app_installation_tasks. self is %s' %self)
    portal=getToolByName(self,'portal_url').getPortalObject()
    if not ISite.providedBy(portal):
        enableSite(portal)

    # modify site properties

    #turn on RSS site wide
    portal_syn = getToolByName(portal,'portal_syndication',None)
    try:
        portal_syn.enableSyndication(portal) 
    except:
        #throws exceptions if already enabled!
            pass
        
    # turn it on in default_member_content
    # need to loop over all folders inside this folder
    default_member_content = getattr(portal,'default_member_content',None)
    for thing in default_member_content.objectValues():
        try:
                portal_syn.enableSyndication(thing) 
        except:
        	#throws exceptions if already enabled!
        	pass

    #set default homepage 
    portal.setLayout('featured_videos_homepage')

    #
    #site security setup!
    #
    secSchema = ISecuritySchema(portal)
    secSchema.set_enable_self_reg(True)
    secSchema.set_enable_user_pwd_choice(True)
    secSchema.set_enable_user_folders(True)

    #
    #setup languages for the site - this is portal languages, not linguaplone
    #
    lang = getToolByName(self, 'portal_languages')
    lang.supported_langs = LANGUAGES
    lang.setDefaultLanguage('en')
    lang.display_flags = 1
    lang.force_language_urls = 1 
    lang.use_cookie_negotiation = 1
    lang.use_content_negotiation = 1
    lang.use_path_negotiation = 1
    lang.use_request_negotiation = 1
    lang.start_neutral = 1


    #
    #ATVocabManager setup
    #
    logger.info('Starting ATVocabManager configuration')
    atvm = getToolByName(portal, ATVOCABULARYTOOL)
    wftool = getToolByName(self,'portal_workflow')
     
    for vkey in vocabs.keys():
        # create vocabulary if it doesnt exist:
        vocabname = vkey
        if atvm.getVocabularyByName(vocabname):
            atvm.manage_delObjects(vocabname)
        logger.debug("adding vocabulary %s" % vocabname)
        atvm.invokeFactory('SimpleVocabulary', vocabname)

        vocab = atvm[vocabname]

        #delete the 'default' item
        if hasattr(vocab, 'default'):
            vocab.manage_delObjects(['default'])
     
        for (ikey, value) in vocabs [vkey]:
            if not hasattr(vocab, ikey):
                vocab.invokeFactory('SimpleVocabularyTerm', ikey)
                logger.debug("adding vocabulary item %s %s" % (ikey,value))
                vocab[ikey].setTitle(value)

        #reindex
        vocab.reindexObject()

    #
    #
    #ATCountryWidget setup
    #reset the country tool
    countrytool = getToolByName(self, CountryUtils.id)
    #common code
    countrytool.manage_countries_reset()
    
    #TODO translate country names like is done in vocabs above
    
    if SE_ASIA_COUNTRIES:
        logger.info('starting custom se-asia countries ATCountryWidget configuration')
        #Add countries missing from the standard installs
        # 
        countrytool.manage_countries_addCountry('WP',_(u'West Papua'))
        #XXX this is a state of America, not a country - but thats just politics!!
        countrytool.manage_countries_addCountry('HA',_(u'Hawaii'))
        countrytool.manage_countries_addCountry('BU',_(u'Bougainville'))
       
        #update three more pre-exisiting countries 
        #change Myanmar to Burma
        #Lao Peoples blah blah to just Laos
        #Viet Nam to Vietnam
        countries = countrytool._country_list
        countries[countries.index(Country('MM'))].name=_(u'Burma')
        countries[countries.index(Country('LA'))].name=_(u'Laos')
        countries[countries.index(Country('VN'))].name=_(u'Vietnam')
        countries[countries.index(Country('NZ'))].name=_(u'NZ-Aotearoa')
      
        #add our areas
        countrytool.manage_countries_addArea(_(u'South East Asia'))
        countrytool.manage_countries_addCountryToArea(_(u'South East Asia'), ['SG','TH','VN','ID','PH','LA','MY','KH','BN','MM','HK','MO'])
        countrytool.manage_countries_sortArea(_(u'South East Asia'))
     
        countrytool.manage_countries_addArea(_(u'Oceania'))
        countrytool.manage_countries_addCountryToArea(_(u'Oceania'), ['AU','NZ','PG','TL','WP','FJ','SB','HA','NC','VU','WS','BU'    ,'NR','TO','TV','GU','KI','FM','PF','MH','MP','PW','PN','TK','AQ',])
        countrytool.manage_countries_sortArea(_(u'Oceania'))

    #
    # Collections for display 
    # latestvideos / featured-videos / news-and-events
    #

    #The front page, @@featured_videos_homepage, contains
    #links to 'featured-videos' which is a smart folder containing
    #all the videos with keyword 'featured' and 'lastestvideos'
    #which is a smart folder of the latest videos. this method will
    #simply install them.

    # Items to deploy on install.
    items = (dict(id      = 'featured-videos',
                  title   = _(u'Featured Videos'),
                  desc    = _(u'Videos featured by the editorial team.'),
                  layout  = "video_listing_view",
                  exclude = True),

             dict(id      = 'latestvideos',
                  title   = _(u'Latest Videos'),
                  desc    = _(u'Latest videos contributed by the users.'),
                  layout  = "video_listing_view",
                  exclude = False),

             dict(id      = 'news_and_events',
                  title   = _(u'News and Events'),
                  desc    = _(u'Latest news and events on the site.'),
                  layout  = "folder_summary_view",
                  exclude = True),
            )

    # Items creation
    for item in items:
        try:
            canon = getattr(self, item['id'])
            deleteTranslations(canon)
            self.manage_delObjects([item['id']])
        except:
            ## This is nasty to silence it all
            pass

        # We create the element
        self.invokeFactory('Topic',
                           id = item['id'],
                           title = item['title'],
                           description = item['desc'].translate({}))

        fv = getattr(self, item['id'])
 

        # We change its ownership and wf status
        publishObject(wftool, fv)

        # Filter results to ATEngageVideo
        # Have to use the name of the Title (and ATEngageVideo will be 
        #    re-named by configATEngageVideo to Video!)
        # this will actually use ALL objects with title 'Video', which 
        #    means atm, ATEngageVideo and ATVideo
        type_criterion = fv.addCriterion('Type', 'ATPortalTypeCriterion')
        if item['id'] is 'news_and_events':
        	type_criterion.setValue( ("News Item","Event") )
        else:
        	type_criterion.setValue("Plumi Video")

        # Filter results to this 'keyword' field, the kw being 'featured'
        if item['id'] is 'featured-videos':
            type_criterion = fv.addCriterion('Subject', 
                                             'ATSimpleStringCriterion')
            type_criterion.setValue('featured')

        # Sort on reverse publication date order
        # XXX port functionality
        #sort_crit = fv.addCriterion('getFirstPublishedTransitionTime',
        #                                "ATSortCriterion")
        sort_crit = fv.addCriterion('created',"ATSortCriterion")
        sort_crit.setReversed(True)

        ## add criteria for showing only published videos
        state_crit = fv.addCriterion('review_state', 'ATSimpleStringCriterion')
        state_crit.setValue('published')

        if item['exclude'] is True:
            fv.setExcludeFromNav(True)

        if item['layout'] is not None:
            fv.setLayout(item['layout'])

        fv.reindexObject()

        createTranslations(self,fv)


    #
    #
    # Taxonomy - smart folder hierarchy setup - genres/categories/countries/ 
    #    for videos we automatically [RE]create collections , hierarchically, 
    #    for all available vocabulary items
    #
    logger.info('starting taxonomy hierarchy setup')

    #delete the taxonomy folder and it's translations.
    #this should also delete all children and children's children etc
    try:
        canon = getattr(self, 'taxonomy')
        deleteTranslations(canon)
        self.manage_delObjects(['taxonomy'])
    except:
        pass
    self.invokeFactory('Folder', id = TOPLEVEL_TAXONOMY_FOLDER,
                       title = _(u'Browse Content'),
#                      description = _(u'The top-level taxonomy of the content')
                       )
    taxonomy_fldr = getattr(self,TOPLEVEL_TAXONOMY_FOLDER,None) 
    # we start in 'taxonomy', and shld already have sub-folders constructed
    #    to hold the topics objects (smart folders), via generic setup XML
    publishObject(wftool,taxonomy_fldr)

    createTranslations(self,taxonomy_fldr)
    layout_name = "video_listing_view"


    #
    # 1 of 4: video genre
    #
    taxonomy_fldr.invokeFactory('Folder', id=GENRE_FOLDER, 
                                title=_(u'Video Genres'))
    genre_fldr = getattr(taxonomy_fldr, GENRE_FOLDER,None)
    publishObject(wftool,genre_fldr)
    createTranslations(self,genre_fldr)
    #description string for new smart folders
    for vocab in vocabs['video_genre']:
        new_smart_fldr_id = vocab[0]
        #make the new SmartFolder
        genre_fldr.invokeFactory('Topic', id=new_smart_fldr_id,title=vocab[1])
        fldr = getattr(genre_fldr,new_smart_fldr_id)
         
        # Filter results to Plumi Video
        type_criterion = fldr.addCriterion('Type', 'ATPortalTypeCriterion' )
        #Have to use the name of the Title of the Type you want to filter.
        type_criterion.setValue("Plumi Video")
         
        # Filter results to this individual genre
        type_criterion = fldr.addCriterion('getGenre', 'ATSimpleStringCriterion' )
        #match against the ID of the vocab term. see getGenre in content types 
        type_criterion.setValue(vocab[0])
        ## add criteria for showing only published videos
        state_crit = fldr.addCriterion('review_state', 'ATSimpleStringCriterion')
        state_crit.setValue('published')
        
        #XXX used to have a custom getFirstPublishedTransitionTime 
        #sort on reverse date order, using the first published time transition
        sort_crit = fldr.addCriterion('modified',"ATSortCriterion")
        sort_crit.setReversed(True)

        #make the folder published
        fldr.setLayout(layout_name)
        publishObject(wftool,fldr)
        createTranslations(self,fldr)

    #
    # 2 of 4: video categories aka topic
    #
    taxonomy_fldr.invokeFactory('Folder',id=CATEGORIES_FOLDER,
                                title=_(u'Video Topics'))
    categ_fldr = getattr(taxonomy_fldr, CATEGORIES_FOLDER,None)
    publishObject(wftool,categ_fldr)
    createTranslations(self,categ_fldr)

    for vocab in vocabs['video_categories']:
        new_smart_fldr_id = vocab[0]

        #make the new SmartFolder
        categ_fldr.invokeFactory('Topic', id=new_smart_fldr_id,title=vocab[1])
        fldr = getattr(categ_fldr,new_smart_fldr_id)

        # Filter results to Plumi Video
        type_criterion = fldr.addCriterion('Type', 'ATPortalTypeCriterion' )
        type_criterion.setValue("Plumi Video")
        # Filter results to this individual category
        type_criterion = fldr.addCriterion('getCategories', 'ATListCriterion' )
        #match against the ID of the vocab term. see getCategories in content objects
        type_criterion.setValue(vocab[0])
        #match if any vocab term is present in the video's selected categories
        type_criterion.setOperator('or')
        ## add criteria for showing only published videos
        state_crit = fldr.addCriterion('review_state', 'ATSimpleStringCriterion')
        state_crit.setValue('published')
        #sort on reverse date order
        #XXX old getfirstpublishedtransition time 
        sort_crit = fldr.addCriterion('modified',"ATSortCriterion")
        sort_crit.setReversed(True)

        #make the folder published.
        fldr.setLayout(layout_name)
        publishObject(wftool,fldr)
        createTranslations(self,fldr)


    #
    # 3 of 4: video countries
    #
   
    #Countries
    #get the countries from the countrytool!
    # nb: this means that the setup method for the countries should be called BEFORE
    # this one

    countrytool = getToolByName(self,CountryUtils.id)
    cdict = list()
    taxonomy_fldr.invokeFactory('Folder',id=COUNTRIES_FOLDER,
                                title=_(u'Countries'))
    countries_fldr = getattr(taxonomy_fldr,COUNTRIES_FOLDER,None)
    publishObject(wftool,countries_fldr)
    createTranslations(self,countries_fldr)

    for area in countrytool._area_list:
        for country in area.countries:
            cdict.append([country.isocc,country.name])

    for country in cdict:
        new_smart_fldr_id = country[0]

        #make the new SmartFolder
        countries_fldr.invokeFactory('Topic', id=new_smart_fldr_id,title=country[1]) 
        fldr = getattr(countries_fldr,new_smart_fldr_id)

        # Filter results to  Plumi Video
        type_criterion = fldr.addCriterion('Type', 'ATPortalTypeCriterion' )
        type_criterion.setValue("Plumi Video")

        # Filter results to this individual category
        type_criterion = fldr.addCriterion('getCountries', 'ATListCriterion' )
        #
        #match against the ID of the vocab term. see getCategories in content objects
        type_criterion.setValue(country[0])
        #match if any vocab term is present in the video's selected categories
        type_criterion.setOperator('or')
        ## add criteria for showing only published videos
        state_crit = fldr.addCriterion('review_state', 'ATSimpleStringCriterion')
        state_crit.setValue('published')
        #sort on reverse date order
        sort_crit = fldr.addCriterion('modified',"ATSortCriterion")
        sort_crit.setReversed(True)
        #publish folder
        fldr.setLayout(layout_name)
        publishObject(wftool,fldr)
        createTranslations(self,fldr)

    #
    #4 of 4 : CallOut submission categories
    #
    topic_description_string = "CallOuts for Topic - %s "
    taxonomy_fldr.invokeFactory('Folder',id=SUBMISSIONS_FOLDER,
                                title=_(u'Call Outs'))
    submissions_fldr = getattr(taxonomy_fldr,SUBMISSIONS_FOLDER,None)
    publishObject(wftool,submissions_fldr)
    createTranslations(self,submissions_fldr)

    for submission_categ in vocabs['submission_categories']:
        new_smart_fldr_id = submission_categ[0]

        #make the new SmartFolder
        submissions_fldr.invokeFactory('Topic', id=new_smart_fldr_id,title=submission_categ[1])
        fldr = getattr(submissions_fldr,new_smart_fldr_id)
        # Filter results to Callouts
        type_criterion = fldr.addCriterion('Type', 'ATPortalTypeCriterion' )
        #the title of the type, not the class name, or portal_type 
        type_criterion.setValue("Plumi Call Out")

        # Filter results to this individual category
        type_criterion = fldr.addCriterion('getSubmissionCategories', 'ATListCriterion' )
        #
        #match against the ID of the vocab term. see getCategories in callout.py (Callout object)
        type_criterion.setValue(submission_categ[0])
        #match if any vocab term is present in the video's selected categories
        type_criterion.setOperator('or')

        ## add criteria for showing only published videos
        state_crit = fldr.addCriterion('review_state', 'ATSimpleStringCriterion')
        state_crit.setValue('published')
        #sort on reverse date order
        sort_crit = fldr.addCriterion('modified',"ATSortCriterion")
        sort_crit.setReversed(True)
        #publish the folder
        fldr.setLayout(layout_name)
        publishObject(wftool,fldr)
        createTranslations(self,fldr)




from setuptools import setup, find_packages
import os

version = '0.2'

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

long_description = (
    read('README.txt')
    + '\n' +
    'Change history\n'
    '**************\n'
    + '\n' +
    read('CHANGES.txt')
    + '\n' +
    'Contributors\n'
    '************\n'
    + '\n' +
    read('CONTRIBUTORS.txt')
    )

setup(name='plumi.app',
      version=version,
      description="Plumi application setup",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='plone plumi policy',
      author='Andy Nicholson',
      author_email='andy@engagemedia.org',
      url='https://svn.plone.org/svn/collective/plumi.app/trunk',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['plumi', 'plumi.app'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      [z3c.autoinclude.plugin]
      target = plone

      """,
      )
